John Paul Wallington | 15 May 21:37
X-Face
Favicon

change w3-default-homepage

Ahoy,

The existing w3-default-homepage is a 404 at cs.indiana.edu.
How about making it w3's page at www.gnu.org?

2008-05-15  John Paul Wallington  <jpw <at> pobox.com>

	* lisp/w3.el (w3-do-setup): Fall back to
	http://www.gnu.org/software/w3/ instead of
	http://www.cs.indiana.edu/elisp/w3/docs.html when setting
	`w3-default-homepage'.

diff --git a/lisp/w3.el b/lisp/w3.el
index a23131f..a4c2d5b 100644
--- a/lisp/w3.el
+++ b/lisp/w3.el
@@ -1852,11 +1852,11 @@ Emacs."
     (or w3-hotlist (w3-parse-hotlist))

     ;; Set the default home page, honoring their defaults, then the
     ;; standard WWW_HOME, then default to the documentation @ IU
     (or w3-default-homepage
 	(setq w3-default-homepage
 	      (or (getenv "WWW_HOME")
-		  "http://www.cs.indiana.edu/elisp/w3/docs.html")))
+		  "http://www.gnu.org/software/w3/")))

     (run-hooks 'w3-load-hook)))
@@ -1852,11 +1852,11 @@ Emacs."

     ;; Set the default home page, honoring their defaults, then the
-    ;; standard WWW_HOME, then default to the documentation @ IU
+    ;; standard WWW_HOME, then default to the www.gnu.org w3 Project Page
     (or w3-default-homepage
 	(setq w3-default-homepage

Gmane